summaryrefslogtreecommitdiffstats
path: root/kig/misc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:43 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:43 -0600
commit2d7b541a4e0095d40e37aaefbf9c4a9b9d149302 (patch)
tree628c1676b27475e583cfd0c2105bb41b646654bf /kig/misc
parent6c3f7a55fb7888efc80a7350ef0c2f46ee02baa3 (diff)
downloadtdeedu-2d7b541a4e0095d40e37aaefbf9c4a9b9d149302.tar.gz
tdeedu-2d7b541a4e0095d40e37aaefbf9c4a9b9d149302.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 6c3f7a55fb7888efc80a7350ef0c2f46ee02baa3.
Diffstat (limited to 'kig/misc')
-rw-r--r--kig/misc/calcpaths.cc16
-rw-r--r--kig/misc/calcpaths.h4
-rw-r--r--kig/misc/coordinate_system.cpp16
-rw-r--r--kig/misc/guiaction.cc8
-rw-r--r--kig/misc/kigfiledialog.cc2
-rw-r--r--kig/misc/kiginputdialog.cc4
-rw-r--r--kig/misc/kigpainter.cpp8
-rw-r--r--kig/misc/lists.cc10
-rw-r--r--kig/misc/object_hierarchy.cc10
-rw-r--r--kig/misc/object_hierarchy.h2
-rw-r--r--kig/misc/special_constructors.cc14
11 files changed, 47 insertions, 47 deletions
diff --git a/kig/misc/calcpaths.h b/kig/misc/calcpaths.h
index 620558a3..f81ddc09 100644
--- a/kig/misc/calcpaths.h
+++ b/kig/misc/calcpaths.h
@@ -30,7 +30,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& os );
/**
* This is a different function for more or less the same purpose. It
* takes a few Objects, which are considered to have been calced
- * already. Then, it puts the necessary part of their children in the
+ * already. Then, it puts the necessary part of their tqchildren in the
* right order, so that calc()-ing correctly updates all of their data
* ( they're calc'ed in the right order, i mean... ). The objects in
* from are normally not included in the output, unless they appear
@@ -42,7 +42,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& from, con
* This function returns all objects on the side of the path through
* the dependency tree from from down to to. This means that we look
* for any objects that don't depend on any of the objects in from
- * themselves, but of which one of the direct children does. We need
+ * themselves, but of which one of the direct tqchildren does. We need
* this function for Locus stuff...
*/
std::vector<ObjectCalcer*> sideOfTreePath( const std::vector<ObjectCalcer*>& from, const ObjectCalcer* to );
diff --git a/kig/misc/coordinate_system.cpp b/kig/misc/coordinate_system.cpp
index 36cfef0b..10bd96ce 100644
--- a/kig/misc/coordinate_system.cpp
+++ b/kig/misc/coordinate_system.cpp
@@ -116,19 +116,19 @@ void CoordinateValidator::fixup( TQString & input ) const
sc = input.length();
KLocale* l = KGlobal::locale();
if ( mpolar )
- input.append( TQString::fromLatin1( ";" ) + l->positiveSign() +
- TQString::fromLatin1( "0°" ) );
+ input.append( TQString::tqfromLatin1( ";" ) + l->positiveSign() +
+ TQString::tqfromLatin1( "0°" ) );
else
- input.append( TQString::fromLatin1( ";" ) + l->positiveSign() +
- TQString::fromLatin1( "0" ) + l->decimalSymbol() +
- TQString::fromLatin1( "0" ) );
+ input.append( TQString::tqfromLatin1( ";" ) + l->positiveSign() +
+ TQString::tqfromLatin1( "0" ) + l->decimalSymbol() +
+ TQString::tqfromLatin1( "0" ) );
};
mre.exactMatch( input );
TQString ds1 = mre.cap( 1 );
mdv.fixup( ds1 );
TQString ds2 = mre.cap( 2 );
mdv.fixup( ds2 );
- input = ds1 + TQString::fromLatin1( "; " ) + ds2;
+ input = ds1 + TQString::tqfromLatin1( "; " ) + ds2;
}
EuclideanCoords::EuclideanCoords()
@@ -146,7 +146,7 @@ TQString EuclideanCoords::fromScreen( const Coordinate& p, const KigDocument& d
int l = kigMax( 0, (int) ( 3 - log10( m ) ) );
TQString xs = KGlobal::locale()->formatNumber( p.x, l );
TQString ys = KGlobal::locale()->formatNumber( p.y, l );
- return TQString::fromLatin1( "( %1; %2 )" ).arg( xs ).arg( ys );
+ return TQString::tqfromLatin1( "( %1; %2 )" ).tqarg( xs ).tqarg( ys );
}
Coordinate EuclideanCoords::toScreen(const TQString& s, bool& ok) const
@@ -354,7 +354,7 @@ TQString PolarCoords::fromScreen( const Coordinate& pt, const KigDocument& d ) c
TQString rs = KGlobal::locale()->formatNumber( r, l );
TQString ts = KGlobal::locale()->formatNumber( theta, 0 );
- return TQString::fromLatin1("( %1; %2° )").arg( rs ).arg( ts );
+ return TQString::tqfromLatin1("( %1; %2° )").tqarg( rs ).tqarg( ts );
}
TQString PolarCoords::coordinateFormatNotice() const
diff --git a/kig/misc/guiaction.cc b/kig/misc/guiaction.cc
index d42b7ca4..f19f2d82 100644
--- a/kig/misc/guiaction.cc
+++ b/kig/misc/guiaction.cc
@@ -223,7 +223,7 @@ void AddFixedPointAction::act( KigPart& doc )
KigInputDialog::getCoordinate(
i18n( "Fixed Point" ),
i18n( "Enter the coordinates for the new point." ) +
- TQString::fromLatin1( "<br>" ) +
+ TQString::tqfromLatin1( "<br>" ) +
doc.document().coordinateSystem().coordinateFormatNoticeMarkup(),
doc.widget(), &ok, doc.document(), &c );
if ( ! ok ) return;
@@ -272,7 +272,7 @@ TestAction::~TestAction()
TQString TestAction::description() const
{
- return TQString::fromLatin1( "Test stuff !!!" );
+ return TQString::tqfromLatin1( "Test stuff !!!" );
}
TQCString TestAction::iconFileName() const
@@ -282,7 +282,7 @@ TQCString TestAction::iconFileName() const
TQString TestAction::descriptiveName() const
{
- return TQString::fromLatin1( "Test stuff !!!" );
+ return TQString::tqfromLatin1( "Test stuff !!!" );
}
const char* TestAction::actionName() const
@@ -297,7 +297,7 @@ void TestAction::act( KigPart& doc )
Object* constantpoint = ObjectFactory::instance()->fixedPoint( Coordinate( -1, -1 ) );
constantpoint->calc( doc );
- Object* codeobject = new DataObject( new StringImp( TQString::fromLatin1( script ) ) );
+ Object* codeobject = new DataObject( new StringImp( TQString::tqfromLatin1( script ) ) );
Object* compiledcode = new RealObject( PythonCompileType::instance(), Objects( codeobject ) );
compiledcode->calc( doc );
diff --git a/kig/misc/kigfiledialog.cc b/kig/misc/kigfiledialog.cc
index 2d7ea08f..2c211690 100644
--- a/kig/misc/kigfiledialog.cc
+++ b/kig/misc/kigfiledialog.cc
@@ -53,7 +53,7 @@ void KigFileDialog::accept()
{
int ret = KMessageBox::warningContinueCancel( this,
i18n( "The file \"%1\" already exists. Do you wish to overwrite it?" )
- .arg( sFile ), i18n( "Overwrite File?" ), i18n("Overwrite") );
+ .tqarg( sFile ), i18n( "Overwrite File?" ), i18n("Overwrite") );
if ( ret != KMessageBox::Continue )
{
KFileDialog::reject();
diff --git a/kig/misc/kiginputdialog.cc b/kig/misc/kiginputdialog.cc
index 61d89883..99e635b2 100644
--- a/kig/misc/kiginputdialog.cc
+++ b/kig/misc/kiginputdialog.cc
@@ -28,7 +28,7 @@
#include "../kig/kig_document.h"
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqpushbutton.h>
#include <tqvalidator.h>
#include <tqwhatsthis.h>
@@ -85,7 +85,7 @@ KigInputDialog::KigInputDialog( const TQString& caption, const TQString& label,
d->m_textEdit->setText( label );
d->m_textEdit->setReadOnly( true );
d->m_textEdit->setFocusPolicy( TQ_NoFocus );
-// d->m_textEdit->setAlignment( d->m_textEdit->alignment() | TQt::WordBreak );
+// d->m_textEdit->tqsetAlignment( d->m_textEdit->tqalignment() | TQt::WordBreak );
d->m_textEdit->setFrameStyle( TQFrame::NoFrame );
mainlay->addWidget( d->m_textEdit );
diff --git a/kig/misc/kigpainter.cpp b/kig/misc/kigpainter.cpp
index 4b3ede2e..81ae6574 100644
--- a/kig/misc/kigpainter.cpp
+++ b/kig/misc/kigpainter.cpp
@@ -300,7 +300,7 @@ void KigPainter::drawPolygon( const std::vector<TQPoint>& pts,
{
t.putPoints( c++, 1, i->x(), i->y() );
};
- mP.drawPolygon( t, winding, index, npoints );
+ mP.tqdrawPolygon( t, winding, index, npoints );
setPen( oldpen );
setBrush( oldbrush );
if( mNeedOverlay ) mOverlay.push_back( t.boundingRect() );
@@ -645,7 +645,7 @@ void KigPainter::drawAngle( const Coordinate& cpoint, const double dstartangle,
setBrushStyle( Qt::SolidPattern );
// drawPolygon( arrow );
- mP.drawPolygon( arrow, false, 0, -1 );
+ mP.tqdrawPolygon( arrow, false, 0, -1 );
// if ( mNeedOverlay ) mOverlay.push_back( toScreen( r ) );
setWholeWinOverlay(); //mp: ugly! why not compute a correct overlay?
@@ -859,7 +859,7 @@ void KigPainter::drawCurve( const CurveImp* curve )
if ( curpolylinenextfree > 0 && curpolyline[curpolylinenextfree - 1] != tp1 )
{
// flush the current part of the curve
- mP.drawPolyline( curpolyline, 0, curpolylinenextfree );
+ mP.tqdrawPolyline( curpolyline, 0, curpolylinenextfree );
curpolylinenextfree = 0;
}
if ( curpolylinenextfree == 0 )
@@ -883,7 +883,7 @@ void KigPainter::drawCurve( const CurveImp* curve )
}
}
// flush the rest of the curve
- mP.drawPolyline( curpolyline, 0, curpolylinenextfree );
+ mP.tqdrawPolyline( curpolyline, 0, curpolylinenextfree );
curpolylinenextfree = 0;
if ( ! workstack.empty () )
diff --git a/kig/misc/lists.cc b/kig/misc/lists.cc
index a294105e..7d2bee62 100644
--- a/kig/misc/lists.cc
+++ b/kig/misc/lists.cc
@@ -27,7 +27,7 @@
#include <klocale.h>
#include <kmessagebox.h>
#include <tqfile.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqdom.h>
#include <tqregexp.h>
#include <algorithm>
@@ -301,13 +301,13 @@ bool MacroList::load( const TQString& f, std::vector<Macro*>& ret, const KigPart
TQFile file( f );
if ( ! file.open( IO_ReadOnly ) )
{
- KMessageBox::sorry( 0, i18n( "Could not open macro file '%1'" ).arg( f ) );
+ KMessageBox::sorry( 0, i18n( "Could not open macro file '%1'" ).tqarg( f ) );
return false;
}
TQDomDocument doc( "KigMacroFile" );
if ( !doc.setContent( &file ) )
{
- KMessageBox::sorry( 0, i18n( "Could not open macro file '%1'" ).arg( f ) );
+ KMessageBox::sorry( 0, i18n( "Could not open macro file '%1'" ).tqarg( f ) );
return false;
}
file.close();
@@ -318,7 +318,7 @@ bool MacroList::load( const TQString& f, std::vector<Macro*>& ret, const KigPart
else
{
KMessageBox::detailedSorry(
- 0, i18n( "Kig cannot open the macro file \"%1\"." ).arg( f ),
+ 0, i18n( "Kig cannot open the macro file \"%1\"." ).tqarg( f ),
i18n( "This file was created by a very old Kig version (pre-0.4). "
"Support for this format has been removed from recent Kig versions. "
"You can try to import this macro using a previous Kig version "
@@ -372,7 +372,7 @@ bool MacroList::loadNew( const TQDomElement& docelem, std::vector<Macro*>& ret,
assert( hierarchy );
// if the macro has no name, we give it a bogus name...
if ( name.isEmpty() )
- name = i18n( "Unnamed Macro #%1" ).arg( unnamedindex++ );
+ name = i18n( "Unnamed Macro #%1" ).tqarg( unnamedindex++ );
MacroConstructor* ctor =
new MacroConstructor( *hierarchy, i18n( name.latin1() ), i18n( description.latin1() ), iconfile );
delete hierarchy;
diff --git a/kig/misc/object_hierarchy.cc b/kig/misc/object_hierarchy.cc
index da89b66c..e72a3c19 100644
--- a/kig/misc/object_hierarchy.cc
+++ b/kig/misc/object_hierarchy.cc
@@ -419,10 +419,10 @@ void ObjectHierarchy::serialize( TQDomElement& parent, TQDomDocument& doc ) cons
// we don't save these atm, since the user can't define them.
// we only load them from builtin macro's.
// TQDomElement ut = doc.createElement( "UseText" );
-// ut.appendChild( doc.createTextNode( TQString::fromLatin1(musetexts[i].c_str() ) ) );
+// ut.appendChild( doc.createTextNode( TQString::tqfromLatin1(musetexts[i].c_str() ) ) );
// e.appendChild( ut );
// TQDomElement ss = doc.createElement( "SelectStatement" );
-// ss.appendChild( doc.createTextNode( TQString::fromLatin1(mselectstatements[i].c_str() ) ) );
+// ss.appendChild( doc.createTextNode( TQString::tqfromLatin1(mselectstatements[i].c_str() ) ) );
// e.appendChild( ss );
parent.appendChild( e );
}
@@ -437,7 +437,7 @@ void ObjectHierarchy::serialize( TQDomElement& parent, TQDomDocument& doc ) cons
{
const ApplyTypeNode* node = static_cast<const ApplyTypeNode*>( mnodes[i] );
e.setAttribute( "action", "calc" );
- e.setAttribute( "type", TQString::fromLatin1( node->type()->fullName() ) );
+ e.setAttribute( "type", TQString::tqfromLatin1( node->type()->fullName() ) );
for ( uint i = 0; i < node->parents().size(); ++i )
{
int parent = node->parents()[i] + 1;
@@ -478,7 +478,7 @@ ObjectHierarchy* ObjectHierarchy::buildSafeObjectHierarchy( const TQDomElement&
#define KIG_GENERIC_PARSE_ERROR \
{ \
error = i18n( "An error was encountered at line %1 in file %2." ) \
- .arg( __LINE__ ).arg( __FILE__ ); \
+ .tqarg( __LINE__ ).tqarg( __FILE__ ); \
return 0; \
}
@@ -544,7 +544,7 @@ ObjectHierarchy* ObjectHierarchy::buildSafeObjectHierarchy( const TQDomElement&
"which this Kig version does not support."
"Perhaps you have compiled Kig without support "
"for this object type,"
- "or perhaps you are using an older Kig version." ).arg( TQString(typen) );
+ "or perhaps you are using an older Kig version." ).tqarg( TQString(typen) );
return 0;
}
diff --git a/kig/misc/object_hierarchy.h b/kig/misc/object_hierarchy.h
index 60df8a59..5997015c 100644
--- a/kig/misc/object_hierarchy.h
+++ b/kig/misc/object_hierarchy.h
@@ -73,7 +73,7 @@ public:
std::vector<ObjectImp*> calc( const Args& a, const KigDocument& doc ) const;
/**
- * saves the ObjectHierarchy data in children xml tags of \p parent ..
+ * saves the ObjectHierarchy data in tqchildren xml tags of \p parent ..
*/
void serialize( TQDomElement& parent, TQDomDocument& doc ) const;
/**
diff --git a/kig/misc/special_constructors.cc b/kig/misc/special_constructors.cc
index 51ac346e..edc54b42 100644
--- a/kig/misc/special_constructors.cc
+++ b/kig/misc/special_constructors.cc
@@ -210,14 +210,14 @@ const int LocusConstructor::wantArgs(
if ( dynamic_cast<ObjectTypeCalcer*>( os.front() ) &&
static_cast<ObjectTypeCalcer*>( os.front() )->type()->inherits( ObjectType::ID_ConstrainedPointType ) )
{
- std::set<ObjectCalcer*> children = getAllChildren( os.front() );
- return children.find( os.back() ) != children.end() ? ret : ArgsParser::Invalid;
+ std::set<ObjectCalcer*> tqchildren = getAllChildren( os.front() );
+ return tqchildren.find( os.back() ) != tqchildren.end() ? ret : ArgsParser::Invalid;
}
if ( dynamic_cast<ObjectTypeCalcer*>( os.back() ) &&
static_cast<ObjectTypeCalcer*>( os.back() )->type()->inherits( ObjectType::ID_ConstrainedPointType ) )
{
- std::set<ObjectCalcer*> children = getAllChildren( os.back() );
- return children.find( os.front() ) != children.end() ? ret : ArgsParser::Invalid;
+ std::set<ObjectCalcer*> tqchildren = getAllChildren( os.back() );
+ return tqchildren.find( os.front() ) != tqchildren.end() ? ret : ArgsParser::Invalid;
}
return ArgsParser::Invalid;
}
@@ -682,7 +682,7 @@ void PolygonBCVConstructor::handlePrelim(
ptn = PointImp( where );
ptn.draw( p );
if ( i > 5 ) continue;
- text = TextImp( TQString( "(%1)" ).arg(i), where, false );
+ text = TextImp( TQString( "(%1)" ).tqarg(i), where, false );
text.draw( p );
}
p.setStyle( Qt::DotLine );
@@ -752,13 +752,13 @@ TQString PolygonBCVConstructor::useText( const ObjectCalcer&, const std::vector<
{
TQString result = TQString(
i18n( "Adjust the number of sides (%1/%2)" )
- ).arg( nsides ).arg( winding );
+ ).tqarg( nsides ).tqarg( winding );
return result;
} else
{
TQString result = TQString(
i18n( "Adjust the number of sides (%1)" )
- ).arg( nsides );
+ ).tqarg( nsides );
return result;
}
break;
diff --git a/kig/misc/calcpaths.cc b/kig/misc/calcpaths.cc
index 1532715b..3e947789 100644
--- a/kig/misc/calcpaths.cc
+++ b/kig/misc/calcpaths.cc
@@ -75,7 +75,7 @@ void localdfs( ObjectCalcer* obj,
std::vector<ObjectCalcer*>& all)
{
visited.push_back( obj );
- const std::vector<ObjectCalcer*> o = obj->children();
+ const std::vector<ObjectCalcer*> o = obj->tqchildren();
for ( std::vector<ObjectCalcer*>::const_iterator i = o.begin(); i != o.end(); ++i )
{
if ( std::find( visited.begin(), visited.end(), *i ) == visited.end() )
@@ -98,7 +98,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& os )
// the general idea here:
// first we build a new Objects variable. For every object in os,
// we put all of its children at the end of it, and we do the same
// for the ones we add..
// "all" is the Objects var we're building...
@@ -115,7 +115,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& os )
{
for ( std::vector<ObjectCalcer*>::const_iterator i = tmp.begin(); i != tmp.end(); ++i )
{
- const std::vector<ObjectCalcer*> o = (*i)->children();
+ const std::vector<ObjectCalcer*> o = (*i)->tqchildren();
std::copy( o.begin(), o.end(), std::back_inserter( all ) );
std::copy( o.begin(), o.end(), std::back_inserter( tmp2 ) );
};
@@ -148,7 +148,7 @@ bool addBranch( const std::vector<ObjectCalcer*>& o, const ObjectCalcer* to, std
if ( *i == to )
rb = true;
else
- if ( addBranch( (*i)->children(), to, ret ) )
+ if ( addBranch( (*i)->tqchildren(), to, ret ) )
{
rb = true;
ret.push_back( *i );
@@ -163,7 +163,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& from, con
for ( std::vector<ObjectCalcer*>::const_iterator i = from.begin(); i != from.end(); ++i )
{
- (void) addBranch( (*i)->children(), to, all );
+ (void) addBranch( (*i)->tqchildren(), to, all );
};
std::vector<ObjectCalcer*> ret;
@@ -193,7 +193,7 @@ static bool visit( const ObjectCalcer* o, const std::vector<ObjectCalcer*>& from
// this function returns true if the visited object depends on one
// of the objects in from. If we encounter objects that are on the
// side of the tree path ( they do not depend on from themselves,
// but their direct children do ), then we add them to ret.
if ( std::find( from.begin(), from.end(), o ) != from.end() ) return true;
std::vector<bool> deps( o->parents().size(), false );
@@ -289,8 +289,8 @@ std::set<ObjectCalcer*> getAllChildren( const std::vector<ObjectCalcer*> objs )
i != cur.end(); ++i )
{
ret.insert( *i );
- std::vector<ObjectCalcer*> children = (*i)->children();
- next.insert( children.begin(), children.end() );
+ std::vector<ObjectCalcer*> tqchildren = (*i)->tqchildren();
+ next.insert( tqchildren.begin(), tqchildren.end() );
};
cur = next;
};
@@ -98,7 +98,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& os )
// the general idea here:
// first we build a new Objects variable. For every object in os,
- // we put all of its children at the end of it, and we do the same
+ // we put all of its tqchildren at the end of it, and we do the same
// for the ones we add..
// "all" is the Objects var we're building...
@@ -193,7 +193,7 @@ static bool visit( const ObjectCalcer* o, const std::vector<ObjectCalcer*>& from
// of the objects in from. If we encounter objects that are on the
// side of the tree path ( they do not depend on from themselves,
- // but their direct children do ), then we add them to ret.
+ // but their direct tqchildren do ), then we add them to ret.
if ( std::find( from.begin(), from.end(), o ) != from.end() ) return true;
std::vector<bool> deps( o->parents().size(), false );